#!/bin/bash

# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

powerai_save_var_initial() {
    # Save the value of an environment variable if conda environment is
    # being activated for the first time. Used for environment variables
    # that we need to change and want to restore to the original state
    # when conda is deactivated.
    local package="$1"
    local orig_var="$2"
    local orig_val
    local save_var="POWERAI_${package}_${orig_var}"
    local save_val

    eval "save_val=\${${save_var}-xxx}"
    if [ "$save_val" = xxx ]
    then
        # The save variable being unset implies this is the initial
        # conda activation, so save the original value. Note we must
        # use different strings (e.g. 'xxx' vs 'unset') in our tests for
        # unset to distinguish between save_var actually being unset
        # versus being set to the value that indicates the original
        # variable was unset.
        eval "orig_val=\${${orig_var}-unset}"
        eval "export $save_var=$orig_val"
    fi
}

powerai_save_var_initial caffe CAFFE_BIN
powerai_save_var_initial caffe OMP_NUM_THREADS

export CAFFE_BIN=${CONDA_PREFIX}/bin
export OMP_NUM_THREADS=16
